﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.EntityFrameworkCore;

namespace avalonia_with_entity.Models;

public partial class _43pChernovContext : DbContext
{
    public _43pChernovContext()
    {
    }

    public _43pChernovContext(DbContextOptions<_43pChernovContext> options)
        : base(options)
    {
    }

    public virtual DbSet<Course> Courses { get; set; }

    public virtual DbSet<Gender> Genders { get; set; }

    public virtual DbSet<Lesson> Lessons { get; set; }

    public virtual DbSet<Teacher> Teachers { get; set; }

    public virtual DbSet<TeacherCourse> TeacherCourses { get; set; }

    public virtual DbSet<TeacherLesson> TeacherLessons { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
    {
        //нгк
        //optionsBuilder.UseNpgsql("Host=edu.pg.ngknn.local;Port=5432;Database=43P_Chernov;Username=43P;Password=444444");
        //вне нгк
        optionsBuilder.UseNpgsql("Host=edu.pg.ngknn.ru;Port=5442;Database=43P_Chernov;Username=43P;Password=444444");
    }

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Course>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("course_pkey");

            entity.ToTable("course");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Course1).HasColumnName("course");
            entity.Property(e => e.Hour).HasColumnName("hour");
        });

        modelBuilder.Entity<Gender>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("gender_pkey");

            entity.ToTable("gender");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Gender1).HasColumnName("gender");
        });

        modelBuilder.Entity<Lesson>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("lesson_pkey");

            entity.ToTable("lesson");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Lesson1).HasColumnName("lesson");
        });

        modelBuilder.Entity<Teacher>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("teacher_pkey");

            entity.ToTable("teacher");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Birthday)
                .HasColumnType("timestamp without time zone")
                .HasColumnName("birthday");
            entity.Property(e => e.Email).HasColumnName("email");
            entity.Property(e => e.Experience)
                .HasDefaultValueSql("0")
                .HasColumnName("experience");
            entity.Property(e => e.GenderId).HasColumnName("gender_id");
            entity.Property(e => e.Name).HasColumnName("name");
            entity.Property(e => e.Patronymic).HasColumnName("patronymic");
            entity.Property(e => e.Phone).HasColumnName("phone");
            entity.Property(e => e.Surname).HasColumnName("surname");

            entity.HasOne(d => d.Gender).WithMany(p => p.Teachers)
                .HasForeignKey(d => d.GenderId)
                .HasConstraintName("fk_gender_to_teacher");
        });

        modelBuilder.Entity<TeacherCourse>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("teacher_course_pkey");

            entity.ToTable("teacher_course");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Course).HasColumnName("course");
            entity.Property(e => e.Teacher).HasColumnName("teacher");

            entity.HasOne(d => d.CourseNavigation).WithMany(p => p.TeacherCourses)
                .HasForeignKey(d => d.Course)
                .HasConstraintName("fk_course_to_tc");

            entity.HasOne(d => d.TeacherNavigation).WithMany(p => p.TeacherCourses)
                .HasForeignKey(d => d.Teacher)
                .HasConstraintName("fk_teacher_to_tc");
        });

        modelBuilder.Entity<TeacherLesson>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("teacher_lessons_pkey");

            entity.ToTable("teacher_lessons");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Lesson).HasColumnName("lesson");
            entity.Property(e => e.Teacher).HasColumnName("teacher");

            entity.HasOne(d => d.LessonNavigation).WithMany(p => p.TeacherLessons)
                .HasForeignKey(d => d.Lesson)
                .HasConstraintName("fk_lesson_to_tl");

            entity.HasOne(d => d.TeacherNavigation).WithMany(p => p.TeacherLessons)
                .HasForeignKey(d => d.Teacher)
                .HasConstraintName("fk_teacher_to_tl");
        });

        OnModelCreatingPartial(modelBuilder);
    }

    partial void OnModelCreatingPartial(ModelBuilder modelBuilder);
}
