﻿using avalonia_with_entity.Models;
using Microsoft.EntityFrameworkCore;
using ReactiveUI;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace avalonia_with_entity.ViewModels
{
    internal class AddTeacherViewModel : ViewModelBase
    {
        private Teacher? _teacher;
        private string _header;
        private string _buttonAdd;
        private bool _stateAdd;
        public Teacher? CurrentTeacher
        {
            get => _teacher;
            set => this.RaiseAndSetIfChanged(ref _teacher, value);
        }
        public string Header => _header;
        public string ButtonAdd => _buttonAdd;
        public bool VisibleHints => _stateAdd;

        public AddTeacherViewModel()
        {
            _stateAdd = true;
            _header = "Создание";
            _buttonAdd = "Добавить";
            _teacher = new Teacher()
            {
                Experience = 0,
                Gender = new Gender()
            };
        }

        public AddTeacherViewModel(Teacher upTeacher, bool isCreateTeacher = false)
        {
            _stateAdd = isCreateTeacher;

            if (isCreateTeacher)
            {
                _header = "Создание";
                _buttonAdd = "Добавить";

                CurrentTeacher = upTeacher;
            }
            else
            {
                _header = "Изменение";
                _buttonAdd = "Изменить";

                CurrentTeacher = MainWindowViewModel.database.Teachers
                                    .Include(gen => gen.Gender)
                                    .Include(course => course.TeacherCourses)
                                        .ThenInclude(course => course.CourseNavigation)
                                    .Include(lesson => lesson.TeacherLessons)
                                        .ThenInclude(lesson => lesson.LessonNavigation)
                                    .FirstOrDefault(x => upTeacher.Id == x.Id);
            }

            TeacherCourses = CurrentTeacher.TeacherCourses.ToList();
            TeacherLessons = CurrentTeacher.TeacherLessons.ToList();
        }

        public List<Gender> Genders => MainWindowViewModel.database.Genders.ToList();

        public List<Course> Courses => MainWindowViewModel.database.Courses.ToList()
                                                        .Except(CurrentTeacher.TeacherCourses
                                                            .Select(x => x.CourseNavigation).ToList())
                                                                .ToList();
        public List<Lesson> Lessons => MainWindowViewModel.database.Lessons.ToList()
                                                    .Except(CurrentTeacher.TeacherLessons
                                                            .Select(x => x.LessonNavigation))
                                                                .ToList();

        private List<TeacherCourse>? _teacherCourses;
        private List<TeacherLesson>? _teacherLessons;

        public List<TeacherCourse>? TeacherCourses
        {
            get => _teacherCourses;
            set => this.RaiseAndSetIfChanged(ref _teacherCourses, value);
        }
        public List<TeacherLesson>? TeacherLessons
        {
            get => _teacherLessons;
            set => this.RaiseAndSetIfChanged(ref _teacherLessons, value);
        }

        public Course? SelectedCourse
        {
            get => null;
            set
            {
                if (value != null)
                {
                    CurrentTeacher.TeacherCourses.Add(new TeacherCourse() { TeacherNavigation = CurrentTeacher, CourseNavigation = value });
                    TeacherCourses = CurrentTeacher.TeacherCourses.ToList();
                    this.RaisePropertyChanged(nameof(Courses));
                }
            }
        }
        public void DelteCourse(TeacherCourse deleteCourse)
        {
            CurrentTeacher.TeacherCourses.Remove(deleteCourse);
            TeacherCourses = CurrentTeacher.TeacherCourses.ToList();
            this.RaisePropertyChanged(nameof(Courses));
        }

        public Lesson? SelectedLesson
        {
            get => null;
            set
            {
                if (value != null)
                {
                    CurrentTeacher.TeacherLessons.Add(new TeacherLesson() { TeacherNavigation = CurrentTeacher, LessonNavigation = value });
                    TeacherLessons = CurrentTeacher.TeacherLessons.ToList();
                    this.RaisePropertyChanged(nameof(Lessons));
                }
            }
        }
        public void DelteLesson(TeacherLesson deleteLesson)
        {
            CurrentTeacher.TeacherLessons.Remove(deleteLesson);
            TeacherLessons = CurrentTeacher.TeacherLessons.ToList();
            this.RaisePropertyChanged(nameof(Lessons));
        }

        //методы для кнопок
        public async Task BackToShowTeacher()
        {
            string message = "Вы хотите отменить " + (_stateAdd ? "создание" : "изменение") + " профиля преподавателя?";

            bool queshion = await MainWindowViewModel.CusmoMSB(message);

            if (queshion)
            {
                MainWindowViewModel.Instance.Page = new ShowTeachers();
            }
        }

        public void GoToAddCourse()
        {
            MainWindowViewModel.Instance.Page = new AddCource(_teacher, _stateAdd);
        }

        public async Task AddTeacher()
        {
            if (GetActiveButtonAdd())
            {
                if (CurrentTeacher.Id == 0)
                {
                    MainWindowViewModel.database.Teachers.Add(CurrentTeacher);
                    await MainWindowViewModel.CusmoMSBforApprove("Преподаватель был добавлен");
                }
                else
                {
                    await MainWindowViewModel.CusmoMSBforApprove("Преподаватель был изменён");
                }

                MainWindowViewModel.database.SaveChanges();

                MainWindowViewModel.Instance.Page = new ShowTeachers();
            }
            else
            {
                await MainWindowViewModel.CusmoMSBforApprove("Не возможно сохранить изменения!\nНе полные данные!");
            }
        }

        private bool GetActiveButtonAdd()
        {
            if (string.IsNullOrEmpty(_teacher.Name)) return false;
            if (string.IsNullOrEmpty(_teacher.Surname)) return false;
            if (string.IsNullOrEmpty(_teacher.Email)) return false;
            if (string.IsNullOrEmpty(_teacher.Gender.Gender1)) return false;
            if (string.IsNullOrEmpty(_teacher.Birthday.ToString())) return false;

            return true;
        }
    }
}
